@@ -11,9 +11,3 @@ try:
 except Exception as ex:  # pragma: no cover
     import warnings
     warnings.warn("Can't import StarletteServer. {0}".format(ex))
-
-try:
-    from .grpc_server import GrpcServer
-except Exception as ex:  # pragma: no cover
-    import warnings
-    warnings.warn("Can't import GrpcServer. {0}".format(ex))
